cocopy package
==============

Submodules
----------

cocopy.cocoplot module
----------------------

.. automodule:: cocopy.cocoplot
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: cocopy
   :members:
   :undoc-members:
   :show-inheritance:
